/**
 * Copyright (C) 2002-2007 - INRIA (www.inria.fr)
 *
 * CAROL: Common Architecture for RMI ObjectWeb Layer
 *
 * This library is developed inside the OW2 Consortium,
 * http://www.ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JRequestInfo.java 1846 2008-06-11 11:59:13Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.carol.rmi.interceptor.api;

import java.util.Collection;

import org.ow2.carol.rmi.interceptor.spi.JServiceContext;


/**
 * Class <code>JRequestInfo</code> is the CAROL JRMP general Request info
 * @author Guillaume Riviere (Guillaume.Riviere@inrialpes.fr)
 * @version 1.0, 15/07/2002
 */
public interface JRequestInfo {

    /**
     * Get the context specified by this id if there is no context corresponding
     * with this id return null
     * @param id the context id
     * @return JServiceContex the specific ServiceContext
     */
    public JServiceContext getRequestServiceContext(int id);

    /**
     * Get the all the request service context if there is no context return
     * null
     * @return Collection the ServiceContexts
     */
    public Collection<JServiceContext> getAllRequestServiceContext();

    /**
     * Get the context specified by this id if there is no context corresponding
     * with this id return null
     * @param id the context id
     * @return JServiceContex the specific ServiceContext
     */
    public JServiceContext getReplyServiceContext(int id);

    /**
     * Get the all the reply service context if there is no context return null
     * @return Collection the ServiceContexts Array
     */
    public Collection<JServiceContext> getAllReplyServiceContext();

    /**
     * true if exit one or more context
     */
    public boolean hasContexts();

    /**
     * clear the service contexts table
     */
    public void clearAllContexts();
}